0.9.9 API documentation: string_cast.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

string_cast.hpp
Go to the documentation of this file.
1
17 #pragma once
18
19 // Dependency:
20 #include "../glm.hpp"
21 #include "../gtc/type_precision.hpp"
22 #include "../gtc/quaternion.hpp"
23 #include "../gtx/dual_quaternion.hpp"
24 #include <string>
25 #include <cmath>
26
27 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
28 # ifndef GLM_ENABLE_EXPERIMENTAL
29 # pragma message("GLM: GLM_GTX_string_cast is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
30 # else
31 # pragma message("GLM: GLM_GTX_string_cast extension included")
32 # endif
33 #endif
34
35 #if(GLM_COMPILER & GLM_COMPILER_CUDA)
36 # error "GLM_GTX_string_cast is not supported on CUDA compiler"
37 #endif
38
39 namespace glm
40 {
43
46 template<typename genType>
47 GLM_FUNC_DECL std::string to_string(genType const& x);
48
50 }//namespace glm
51
52 #include "string_cast.inl"
glm::to_string
GLM_FUNC_DECL std::string to_string(genType const &x)
Create a string from a GLM vector or matrix typed variable.
glm
Definition: common.hpp:20